@@ -24,7 +24,6 @@
 */
 
 #include <QString>
-#include <QRegExp>
 #include <QRegularExpression>
 #include <QPointer>
 #include <QAbstractScrollArea>
@@ -105,9 +104,9 @@ class QCE_EXPORT QDocumentSearch: public QObject
 		
 		void recreateRegExp();
 		
-//		int m_index;
 		Options m_option;
 		QString m_string;
+        QString s; // keep string alive so that corresponding match may refer it, seems to be changed in Qt5.3
         QRegularExpression m_regularExpression;
         QRegularExpressionMatch m_match;
 
