@@ -18,8 +18,9 @@ SearchResultWidget::SearchResultWidget(QWidget *parent) : QWidget(parent), query
 	searchScopeBox->addItem(tr("Current Doc"), static_cast<uint>(SearchQuery::CurrentDocumentScope));
 	searchScopeBox->addItem(tr("All Docs"), static_cast<uint>(SearchQuery::GlobalScope));
 	searchScopeBox->addItem(tr("Project"), static_cast<uint>(SearchQuery::ProjectScope));
+    searchScopeBox->addItem(tr("Files on disk"), static_cast<uint>(SearchQuery::FilesScope));
 	searchScopeBox->setCurrentIndex(ConfigManagerInterface::getInstance()->getOption("Search/ScopeIndex").toInt());
-	connect(searchScopeBox, SIGNAL(currentIndexChanged(int)), SLOT(updateSearch()));
+    connect(searchScopeBox, SIGNAL(currentIndexChanged(int)), this, SLOT(changeScope(int)));
 
 	searchTypeLabel = new QLabel;
 	searchTextLabel = new QLabel;
@@ -31,15 +32,31 @@ SearchResultWidget::SearchResultWidget(QWidget *parent) : QWidget(parent), query
 	replaceTextEdit = new QLineEdit;
 	replaceTextEdit->setClearButtonEnabled(true);
 	replaceButton = new QPushButton(tr("Replace all"));
+    m_replaceByLabel=new QLabel(tr("Replace by:"));
+
+    connect(replaceTextEdit, &QLineEdit::textChanged, this, &SearchResultWidget::replaceTextEditChanged);
+    connect(replaceTextEdit, SIGNAL(returnPressed()), query, SLOT(replaceAll()));
+    connect(replaceButton, &QPushButton::clicked, this, &SearchResultWidget::replaceButtonClicked);
+
+    // special widgets for search in files
+    m_fileFilterBox = new QComboBox;
+    m_fileFilterBox->addItem(tr("TeX files")+" (*.tex)");
+    m_fileFilterBox->addItem(tr("Bib files")+" (*.bib)");
+    m_fileFilterBox->addItem(tr("All files")+" (*)");
+    m_fileFilterBox->setEditable(true);
+    m_fileFilterBox->setVisible(false);
+
+    connect(m_fileFilterBox, SIGNAL(currentIndexChanged(int)), this, SLOT(changeFileFilter(int)));
 
 	hLayout->addWidget(searchScopeBox);
 
 	hLayout->addWidget(searchTypeLabel);
 	hLayout->addWidget(searchTextLabel, 1);
 	hLayout->addWidget(searchAgainButton);
-	hLayout->addWidget(new QLabel(tr("Replace by:")));
+    hLayout->addWidget(m_replaceByLabel);
 	hLayout->addWidget(replaceTextEdit, 1);
 	hLayout->addWidget(replaceButton);
+    hLayout->addWidget(m_fileFilterBox);
 
 	searchTree = new QTreeView(this);
 	searchTree->header()->hide();
@@ -89,12 +106,10 @@ void SearchResultWidget::setQuery(SearchQuery *sq)
 	replaceTextEdit->setEnabled(replaceAllowed);
 	replaceTextEdit->setText(query->replacementText());
 	replaceButton->setEnabled(replaceAllowed);
-	connect(replaceTextEdit, SIGNAL(textChanged(QString)), query, SLOT(setReplacementText(QString)));
-	connect(replaceTextEdit, SIGNAL(returnPressed()), query, SLOT(replaceAll()));
-	connect(replaceButton, SIGNAL(clicked()), query, SLOT(replaceAll()));
 
 	searchTree->setModel(query->model());
-	connect(query, SIGNAL(runCompleted()), this, SLOT(searchCompleted()));
+    connect(query, &SearchQuery::runCompleted, this, &SearchResultWidget::searchCompleted);
+    adaptGUItoScope();
 }
 
 void SearchResultWidget::updateSearch()
@@ -102,6 +117,27 @@ void SearchResultWidget::updateSearch()
 	if (query) query->setScope(searchScope());
 	emit runSearch(query);
 }
+/*!
+ * \brief change UI and update search when mode is changed
+ * \param mode
+ */
+void SearchResultWidget::changeScope(int)
+{
+    adaptGUItoScope();
+    updateSearch();
+}
+/*!
+ * \brief change the file filter for search in file
+ * Stop current search and start a new one
+ * \param mode
+ */
+void SearchResultWidget::changeFileFilter(int)
+{
+    if(query){
+        query->setFileFilter(m_fileFilterBox->currentText());
+        updateSearch();
+    }
+}
 
 void SearchResultWidget::searchCompleted()
 {
@@ -126,16 +162,75 @@ void SearchResultWidget::updateSearchScopeBox(SearchQuery::Scope sc)
 	if (index >= 0)
 		searchScopeBox->setCurrentIndex(index);
 }
+/*!
+ * \brief adapt replace text/current directory to current scope
+ */
+void SearchResultWidget::adaptGUItoScope()
+{
+    const auto scope=searchScope();
+    if(scope<SearchQuery::FilesScope){
+        m_fileFilterBox->setVisible(false);
+        m_replaceByLabel->setText(tr("Replace by:"));
+        replaceButton->setIcon(QIcon());
+        replaceButton->setText(tr("Replace all"));
+        replaceTextEdit->setText(query->replacementText());
+        replaceTextEdit->setEnabled(true);
+    }else{
+        m_fileFilterBox->setVisible(true);
+        m_replaceByLabel->setText(tr("Search in:"));
+        replaceButton->setIcon(getRealIcon("document-open"));
+        replaceButton->setText("");
+        replaceTextEdit->setText(query->searchFolder());
+        replaceTextEdit->setEnabled(false);
+    }
+}
 
 void SearchResultWidget::clickedSearchResult(const QModelIndex &index)
 {
 
-	QDocument *doc = query->model()->getDocument(index);
-	int lineNr = query->model()->getLineNumber(index);
-	if (!doc || lineNr < 0) {
-		return;
-	}
-	emit jumpToSearchResult(doc, lineNr, query);
+    LatexDocument *doc = qobject_cast<LatexDocument*>(query->model()->getDocument(index));
+    int lineNr = query->model()->getLineNumber(index);
+    if (lineNr < 0) return;
+
+    if(doc){
+        emit jumpToSearchResult(doc, lineNr, query);
+    }else{
+        // result from search in files
+        QString fn=query->model()->getFileName(index);
+        emit jumpToFileSearchResult(fn, lineNr, query);
+    }
+}
+/*!
+ * \brief handle click on replace button
+ * Acts differently depending on the search scope
+ * + Current Doc/All Docs/Projects: replace all in txs documents
+ * + Files on disk: show folder browse dialog to select the folder where to search
+ */
+ void SearchResultWidget::replaceButtonClicked()
+{
+    const auto scope=searchScope();
+    if(scope<SearchQuery::FilesScope){
+        query->replaceAll();
+    }else{
+        // search in files
+        QString folder=QFileDialog::getExistingDirectory(this, tr("Select folder where to search"),query->searchFolder());
+        if(folder.isEmpty()) return;
+        query->setSearchFolder(folder);
+        replaceTextEdit->setText(folder);
+        updateSearch();
+    }
+}
+/*!
+ * \brief replaceTextEditChanged slot
+ * update query if scope is not FileScope
+ * Otherwise only update folder with update button
+ * \param text
+ */
+void SearchResultWidget::replaceTextEditChanged(const QString &text)
+{
+    if(searchScope()<SearchQuery::FilesScope){
+        query->setReplacementText(text);
+    }
 }
 
 void SearchResultWidget::clearSearch()
