@@ -113,6 +113,7 @@ void SyntaxCheck::run()
                 speller=newSpeller;
                 mReplacementList=newReplacementList;
                 mFormatList=newFormatList;
+                m_nonTextGrammarFormats=m_newNonTextGrammarFormats;
 			}
 			mLtxCommandLock.unlock();
 		}
@@ -151,14 +152,26 @@ void SyntaxCheck::run()
 		newLine.dlh->lockForWrite();
 		if (newLine.ticket == newLine.dlh->getCurrentTicket()) { // discard results if text has been changed meanwhile
             newLine.dlh->setCookie(QDocumentLine::LEXER_COOKIE,QVariant::fromValue<TokenList>(tl));
+            QList<QFormatRange>grammarOverlays=newLine.dlh->getOverlaysNoLock(m_nonTextGrammarFormats);
             foreach (const Error &elem, newRanges){
                 if(!mSyntaxChecking && (elem.type!=ERR_spelling) && (elem.type!=ERR_highlight) ){
                     // skip all syntax errors
                     continue;
                 }
-                int fmt= elem.type == ERR_spelling ? SpellerUtility::spellcheckErrorFormat : syntaxErrorFormat;
-                fmt= elem.type == ERR_highlight ? elem.format : fmt;
+                int fmt= (elem.type == ERR_spelling) ? SpellerUtility::spellcheckErrorFormat : syntaxErrorFormat;
+                fmt= (elem.type == ERR_highlight) ? elem.format : fmt;
                 newLine.dlh->addOverlayNoLock(QFormatRange(elem.range.first, elem.range.second, fmt));
+                // for ERR_highlight, remove grammarErrors
+                if(m_hideNonTextGrammarErrors && elem.type==ERR_highlight){
+                    for(int i = 0; i<grammarOverlays.size();++i){
+                        const QFormatRange &range=grammarOverlays.at(i);
+                        if(range.offset>=elem.range.first && range.offset<=elem.range.second){
+                            newLine.dlh->removeOverlayNoLock(range);
+                            grammarOverlays.removeAt(i);
+                            --i;
+                        }
+                    }
+                }
             }
             // add comment hightlight if present
             if(commentStart.first>=0){
@@ -291,6 +304,25 @@ void SyntaxCheck::enableSyntaxCheck(const bool enable){
     if (stopped) return;
     mSyntaxChecking=enable;
 }
+/*! \brief hide non text spelling errors
+ * \param hide
+ */
+void SyntaxCheck::setHideNonTextGrammarErrors(const bool hide)
+{
+    m_hideNonTextGrammarErrors=hide;
+}
+/*!
+ * \brief SyntaxCheck::setNonTextGrammarFormats
+ * \param formats
+ */
+void SyntaxCheck::setNonTextGrammarFormats(const QList<int> formats)
+{
+    if (stopped) return;
+    mLtxCommandLock.lock();
+    newLtxCommandsAvailable = true;
+    m_newNonTextGrammarFormats=formats;
+    mLtxCommandLock.unlock();
+}
 /*!
  * \brief set character/text replacementList for spell checking
  * \param replacementList Map for characater/text replacement prior to spellchecking words. E.g. "u -> ü when german is activated
@@ -578,15 +610,21 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
         if(!activeEnv.isEmpty() && activeEnv.top().endingColumn>=0 && tk.start>activeEnv.top().endingColumn){
             Environment env=activeEnv.pop();
         }
-        // special treatment for ExplSyntaxOff
-        // it is used to toggle expl3 mode off
-        if(!activeEnv.isEmpty() && activeEnv.top().name == "expl3"){
+        // handle single command env stop e.g. \ExplSyntaxOff
+        if(tk.type==Token::command){
             const QString word=tk.getText();
-            if( word == "\\ExplSyntaxOff"){
-                activeEnv.pop();
-                continue;
+            if(ltxCommands->possibleCommands["%endEnv"].contains(word)){
+                const QString envName=ltxCommands->environmentAliases.value(word);
+                if(activeEnv.top().name == envName){
+                    activeEnv.pop();
+                    continue;
+                }
             }
-            if(tk.type==Token::commandUnknown || tk.type==Token::command){
+        }
+
+        if(!activeEnv.isEmpty() && activeEnv.top().name == "%expl3"){
+            // special treatment for expl3 commands in expl3 env
+            if((tk.type==Token::commandUnknown || tk.type==Token::command)&&tk.getText()!="\\\\"){ // special treatment for \\ , see #3877
                 // collect next parts
                 // e.g. \cs_new:Npn is split into \cs _ new : Npn
                 const int start = tk.start;
@@ -773,7 +811,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                 }
             }
             word = latexToPlainWordwithReplacementList(word, mReplacementList); //remove special chars
-            if (speller->hideNonTextSpellingErrors && (checkMathEnvActive(activeEnv)||containsEnv("picture", activeEnv)) ){
+            if (speller->hideNonTextSpellingErrors && (checkMathEnvActive(activeEnv)||containsEnv("picture", activeEnv)||containsEnv("pictureHighlight", activeEnv)) ){
                 word.clear();
                 tk.ignoreSpelling=true;
             }else{
@@ -1042,9 +1080,10 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
             // special treatment for \ExplSyntaxOn, \ExplSyntaxOff
             // \ProvidesExplPackage, \ProvidesExplClass and \ProvidesExplFile
             // activate latex3 mode which ignores _ in commandnames
-            if(word=="\\ExplSyntaxOn" || word=="\\ProvidesExplPackage" || word=="\\ProvidesExplClass" || word=="\\ProvidesExplFile"){
+            if(ltxCommands->possibleCommands["%beginEnv"].contains(word)){
+                const QString envName=ltxCommands->environmentAliases.value(word);
                 Environment env;
-                env.name = "expl3";
+                env.name = envName;
                 env.id = 1; // to be changed
                 env.dlh = dlh;
                 env.ticket = ticket;
