@@ -41,17 +41,23 @@ public:
 
     bool isEmpty() const;
 
+    QString getTag();
+    void setTag(const QString &ntag);
     void setShortcut(const QString &sc);
     void setTrigger(const QString &newTrigger);
 
 	QString typedTag() const;
-    void setTypedTag(const QString &m_tag);
+	void setTypedTag(const QString &m_tag);
+	void setType(const Macro::Type &ntype);
 	static QString parseTypedTag(QString typedTag, Macro::Type &retType);
 
 	void parseTriggerLanguage(QLanguageFactory *langFactory);
 	bool isActiveForTrigger(SpecialTrigger trigger) const;
 	bool isActiveForLanguage(QLanguageDefinition *lang) const;
-	bool isActiveForFormat(int format) const;
+    bool hasFormatTriggers() const;
+    QList<int>getFormatTriggers() const;
+    QList<int>getFormatExcludeTriggers() const;
+    QStringList getTriggerInEnvs() const;
 
     bool load(const QString &fileName);
     bool loadFromText(const QString &text);
@@ -74,6 +80,8 @@ private:
 	QString triggerFormatExcludesUnprocessed;
 	QList<int> triggerFormatExcludes;
 
+    QStringList triggerInEnvs;
+
     QString m_shortcut;
 };
 
