@@ -37,7 +37,7 @@ UserMenuDialog::UserMenuDialog(QWidget *parent,  QString name, QLanguageFactory
 
 	connect(ui.okButton, SIGNAL(clicked()), SLOT(slotOk()));
 
-	connect(ui.runScriptButton, SIGNAL(clicked()), SLOT(slotRunScript()));
+	connect(ui.runScriptButton, SIGNAL(clicked()), SLOT(slotExecMacro()));
 
 	connect(ui.pushButtonAdd, SIGNAL(clicked()), SLOT(slotAdd()));
     connect(ui.pushButtonAddFolder, SIGNAL(clicked()), SLOT(slotAddFolder()));
@@ -45,14 +45,18 @@ UserMenuDialog::UserMenuDialog(QWidget *parent,  QString name, QLanguageFactory
 	connect(ui.pushButtonUp, SIGNAL(clicked()), SLOT(slotMoveUp()));
 	connect(ui.pushButtonDown, SIGNAL(clicked()), SLOT(slotMoveDown()));
 
-    connect(ui.pbExport,SIGNAL(clicked()), SLOT(exportMacro()));
+    QMenu *menuExport = new QMenu();
+
+    menuExport->addAction(tr("Export all macros"),this,SLOT(exportAllMacros()));
+
+    ui.tbExport->setMenu(menuExport);
+    connect(ui.tbExport,SIGNAL(clicked()), SLOT(exportMacro()));
     connect(ui.pbImport,SIGNAL(clicked()), SLOT(importMacro()));
     connect(ui.pbBrowse,SIGNAL(clicked()), SLOT(browseMacrosOnRepository()));
 
-
-	connect(ui.radioButtonNormal, SIGNAL(clicked()), SLOT(changeTypeToNormal()));
-	connect(ui.radioButtonEnvironment, SIGNAL(clicked()), SLOT(changeTypeToEnvironment()));
-	connect(ui.radioButtonScript, SIGNAL(clicked()), SLOT(changeTypeToScript()));
+	connect(ui.radioButtonNormal, SIGNAL(clicked()), SLOT(changeType()));
+	connect(ui.radioButtonEnvironment, SIGNAL(clicked()), SLOT(changeType()));
+	connect(ui.radioButtonScript, SIGNAL(clicked()), SLOT(changeType()));
 
 	//editor options
 	ui.tagEdit->setLayout(new QVBoxLayout());
@@ -122,6 +126,7 @@ UserMenuDialog::UserMenuDialog(QWidget *parent,  QString name, QLanguageFactory
 	connect(ui.triggerHelp, SIGNAL(linkActivated(QString)), SLOT(showTooltip()));
 
     codeedit->editor()->clearFocus();
+    ui.pbBrowse->setFocus();
 }
 
 UserMenuDialog::~UserMenuDialog()
@@ -286,27 +291,31 @@ void UserMenuDialog::change(QTreeWidgetItem *current,QTreeWidgetItem *previous)
         if (m.description != ui.teDescription->toPlainText())
             ui.teDescription->setPlainText(m.description);
 
-        if (codeedit->editor()->text() != m.typedTag()) {
-            codeedit->editor()->setText(m.typedTag(), false);
-            setLanguageFromText();
+        if (codeedit->editor()->text() != m.getTag()) {
+            codeedit->editor()->setText(m.getTag(), false);
+            setLanguageFromType(current);
             codeedit->editor()->setFlag(QEditor::CursorOn,false);
             codeedit->editor()->repaintCursor();
         }
     }
 }
 
-void UserMenuDialog::setLanguageFromText(void)
+void UserMenuDialog::setLanguageFromType(QTreeWidgetItem *current)
 {
-	QString line = codeedit->editor()->text(0);
-	if (line == "%SCRIPT") {
-		languages->setLanguage(codeedit->editor(), ".qs");
-		ui.radioButtonScript->setChecked(true);
-	} else if (line.startsWith("%") && !line.startsWith("%%")) {
-		languages->setLanguage(codeedit->editor(), "");
-		ui.radioButtonEnvironment->setChecked(true);
-	} else {
-		languages->setLanguage(codeedit->editor(), "(La)TeX Macro");
-		ui.radioButtonNormal->setChecked(true);
+	if (current==nullptr) return;
+	QVariant v = current->data(0,Qt::UserRole);
+	if(v.isValid()){
+		Macro m = v.value<Macro>();
+		if (m.type==Macro::Script) {
+			languages->setLanguage(codeedit->editor(), ".qs");
+			ui.radioButtonScript->setChecked(true);
+		} else if (m.type==Macro::Environment) {
+			languages->setLanguage(codeedit->editor(), "Plain text");
+			ui.radioButtonEnvironment->setChecked(true);
+		} else {
+			languages->setLanguage(codeedit->editor(), "(La)TeX Macro");
+			ui.radioButtonNormal->setChecked(true);
+		}
 	}
 }
 
@@ -314,12 +323,15 @@ void UserMenuDialog::slotOk()
 {
 	accept();
 }
-void UserMenuDialog::slotRunScript()
+void UserMenuDialog::slotExecMacro()
 {
-	QString script = codeedit->editor()->text();
-	if (script.startsWith("%SCRIPT\n"))
-		script = script.mid(8);
-	emit runScript(script);
+    QTreeWidgetItem *item = ui.treeWidget->currentItem();
+    if (item==nullptr) return;
+    QVariant v = item->data(0,Qt::UserRole);
+    if (v.isValid()){
+        Macro m = v.value<Macro>();
+        emit execMacro(m);
+    }
 }
 
 void UserMenuDialog::slotAdd()
@@ -344,20 +356,23 @@ void UserMenuDialog::slotRemove()
     }
     if(item->type()==0){
         // only confirm for macros, not for folders
-        if (!UtilsUi::txsConfirm(tr("Do you really want to delete the current macro?")))
+        if (!UtilsUi::txsConfirm(tr("Do you really want to delete the current macro(s)?")))
             return;
     }
 
-    QTreeWidgetItem *parent=item->parent();
-    if(parent){
-        int index = parent->indexOfChild(item);
-        QTreeWidgetItem* child = parent->takeChild(index);
-        delete child;
-    }else{
-        int index = ui.treeWidget->indexOfTopLevelItem(item);
-        QTreeWidgetItem* child = ui.treeWidget->takeTopLevelItem(index);
-        delete child;
+    for (QTreeWidgetItem *item : ui.treeWidget->selectedItems()) {
+        QTreeWidgetItem *parent=item->parent();
+        if(parent){
+            int index = parent->indexOfChild(item);
+            QTreeWidgetItem* child = parent->takeChild(index);
+            delete child;
+        }else{
+            int index = ui.treeWidget->indexOfTopLevelItem(item);
+            QTreeWidgetItem* child = ui.treeWidget->takeTopLevelItem(index);
+            delete child;
+        }
     }
+
     if(ui.treeWidget->topLevelItemCount()==0){
         // add empty macro
         slotAdd();
@@ -445,6 +460,22 @@ void UserMenuDialog::exportMacro()
     }
 }
 
+
+/*!
+ * \brief export all macros to given directory
+ * Macro is "Macro_%d.txsMacro"
+ */
+void UserMenuDialog::exportAllMacros(){
+    QList<Macro> macros = getMacros();
+    if (macros.length()==0) return;
+    QString path = QFileDialog::getExistingDirectory(this,tr("Export all macros"),QString(),QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
+    if (path=="") return;
+    int index = 0;
+    foreach (Macro macro, macros) {
+        macro.save(QString("%1/Macro_%2.txsMacro").arg(path).arg(index++));
+    }
+}
+
 void UserMenuDialog::browseMacrosOnRepository(){
     // open special dialog for macro browser
     MacroBrowserUI *mbUI=new MacroBrowserUI(this);
@@ -456,52 +487,39 @@ void UserMenuDialog::browseMacrosOnRepository(){
     }
 }
 
-void UserMenuDialog::changeTypeToNormal()
+void UserMenuDialog::changeType()
 {
-	QString cur = codeedit->editor()->text();
-	languages->setLanguage(codeedit->editor(), "(La)TeX Macro");
-	if (cur.startsWith("%SCRIPT\n")) codeedit->editor()->setText(cur.mid(8), false);
-	else if (cur.startsWith("%") && !cur.startsWith("%%")) codeedit->editor()->setText(cur.mid(1), false);
-    codeedit->editor()->setFlag(QEditor::CursorOn,false);
-    codeedit->editor()->repaintCursor();
-}
-
-void UserMenuDialog::changeTypeToEnvironment()
-{
-	QString cur = codeedit->editor()->text();
-	languages->setLanguage(codeedit->editor(), "");
-	if (cur.startsWith("%SCRIPT\n")) {
-		codeedit->editor()->setText("%" + cur.mid(8), false);
-	} else {
-		if (cur.startsWith("%") && !cur.startsWith("%%")) return;
-		while (cur.startsWith("%%")) cur = cur.remove(0, 2);
-		if (!cur.startsWith("%")) cur = "%" + cur;
-		codeedit->editor()->setText(cur, false);
-	}
-    codeedit->editor()->setFlag(QEditor::CursorOn,false);
-    codeedit->editor()->repaintCursor();
-}
-
-void UserMenuDialog::changeTypeToScript()
-{
-	QString cur = codeedit->editor()->text();
-	languages->setLanguage(codeedit->editor(), ".qs");
-	if (cur.startsWith("%SCRIPT\n")) return;
-	if (cur.startsWith("%") && !cur.startsWith("%%")) cur = cur.mid(1);
-	codeedit->editor()->setText("%SCRIPT\n" + cur, false);
-    codeedit->editor()->setFlag(QEditor::CursorOn,false);
-    codeedit->editor()->repaintCursor();
+    QTreeWidgetItem *item = ui.treeWidget->currentItem();
+    if (item==nullptr) return;
+    QVariant v = item->data(0,Qt::UserRole);
+    if (v.isValid()){
+        Macro m = v.value<Macro>();
+        if (ui.radioButtonNormal->isChecked()) {
+            m.setType(Macro::Snippet);
+            languages->setLanguage(codeedit->editor(), "(La)TeX Macro");
+        }
+        else if (ui.radioButtonEnvironment->isChecked()) {
+            m.setType(Macro::Environment);
+            languages->setLanguage(codeedit->editor(), "Plain text");
+        }
+        else if (ui.radioButtonScript->isChecked()) {
+            m.setType(Macro::Script);
+            languages->setLanguage(codeedit->editor(), ".qs");
+        }
+        item->setData(0,Qt::UserRole,QVariant::fromValue(m));
+        codeedit->editor()->setFlag(QEditor::CursorOn,false);
+        codeedit->editor()->repaintCursor();
+    }
 }
 
 void UserMenuDialog::textChanged()
 {
-	setLanguageFromText();
     QTreeWidgetItem *item=ui.treeWidget->currentItem();
     if(item==nullptr) return;
     QVariant v=item->data(0,Qt::UserRole);
     if(v.isValid()){
         Macro m=v.value<Macro>();
-        m.setTypedTag(codeedit->editor()->text());
+        m.setTag(codeedit->editor()->text());
         item->setData(0,Qt::UserRole,QVariant::fromValue(m));
     }
 }
@@ -559,10 +577,11 @@ void UserMenuDialog::abbrevChanged()
 void UserMenuDialog::triggerChanged()
 {
     // check if trigger is a valid regex
-    const QStringList fixedTriggers{"?txs-start","?new-file","?new-from-template","?load-file","?load-this-file","?save-file","?close-file","?master-changed","?after-typeset","?after-command-run"};
+    const QStringList fixedTriggers{"?txs-start","?new-file","?new-from-template","?load-file","?load-this-file","?save-file","?close-file","?master-changed","?after-typeset","?after-command-run","?highlighted-as","?not-highlighted-as","?language","?inEnv"};
     const QString text=ui.triggerEdit->text();
     QRegularExpression re(text);
-    if(!re.isValid() && !fixedTriggers.contains(text)){
+    bool fixedTriggerFound=std::any_of(fixedTriggers.constBegin(),fixedTriggers.constEnd(),[&text](const QString elem){return text.contains(elem);});
+    if(!re.isValid() && !fixedTriggerFound){
         // syntax error in regex
         ui.triggerEdit->setToolTip(re.errorString()+tr(" (col. %1)").arg(re.patternErrorOffset()));
         ui.triggerEdit->setStyleSheet("QLineEdit { background: orange; color : black; }");
